import * as action from '../../actions'

import { useEffect} from 'react';
import { connect } from 'react-redux';
import { useDropzone } from 'react-dropzone'
import React, {useCallback} from 'react'

const Track = ({track:{url, originalFileName, id3:{title, artist, album}}}) =>
    <li style={{border: '1px solid black', display:'flex', alignItems:'center'}}>
      <div style={{marginRight:'2%'}}>
        <button style={{padding: '10px', margin:'2px'}}> {`>`} </button>
        <button style={{padding: '10px', margin:'2px'}}>| |</button>
        <br/>
        <button style={{padding: '10px', margin:'2px'}}>Add to...</button>
      </div>
      <div style={{textAlign: 'left'}}>
        <h5>{artist || 'Artist: unknown'}</h5> 
        <h6>{album || 'Album: unknown'}</h6>
        <h5>{title || originalFileName}</h5>
        <p>{url}</p>
      </div>
    </li>

const Playlist = ({playlist}) =>
    <>
      <h2>{playlist[0]?.name || 'Playlist'}</h2>
      <ul>
        {(playlist[0]?.tracks || []).map(track => <Track track={track}/>)}
      </ul>
    </>

export const PlaylistConnect = connect(state => ({playlist: state.promise.playlistTracks?.payload || []}))(Playlist)

const PlaylistPage = ({match: {params: {_id}}, getTracks}) => {
  useEffect(() => { getTracks(_id.substring(1)) }, [_id, getTracks])
  return(<PlaylistConnect />)
}
export const PlaylistPageConnect = connect(null, {getTracks: action.actionGetPlaylistById})(PlaylistPage)

const UserTracks = ({user, tracks}) =>
  <>
    <h2>{ user.login || 'My' } tracks:</h2>
    <ul>
      {(tracks || []).map(track => <Track track={track}/>)}
    </ul>
  </>

const UserTracksConnect = connect(state => ({
    tracks: state.promise.userTracks?.payload || [], 
    user: state.promise.userData?.payload || {}
  })
)(UserTracks)

const UserTracksPage = ({match: {params: {_id}}, getUserTracks}) => {
  useEffect(() => { getUserTracks() },[_id, getUserTracks])
  return(<UserTracksConnect/>)
}
export const UserTracksPageConnect = connect(null, {getUserTracks: action.actionGetUserTracks})(UserTracksPage)

const UserTracksDropzone = ({onLoad}) => {
  const onDrop = useCallback(acceptedFiles => {
    onLoad(acceptedFiles[0])
  }, [])
  const {getRootProps, getInputProps, isDragActive} = useDropzone({onDrop})

  return (
    <div {...getRootProps()}>
      <input {...getInputProps()} />
      { isDragActive ? <p>Drop the files here ...</p> : <UserTracksPageConnect /> }
    </div>
  )
}
export const UserTrackDropzoneConnect = connect(null, {onLoad: action.actionLoadFile})(UserTracksDropzone)